Input

Struct Input 

pub struct Input<'a> { /* private fields */ }

Implementations

Source

impl<'a> Input<'a>

pub fn new(buf: &'a mut &'a [u8]) -> Self

pub fn is_empty(&self) -> bool

pub fn len(&self) -> usize

pub fn advance(&mut self, len: usize) -> Result<&[u8], FormatError>

Splits the first len bytes from the input, returning them as a slice and updating the input buffer. Returns an error if there are not enough bytes remaining to fulfill the request.

pub fn local_peek_bytes(&self, len: usize) -> Result<&[u8], FormatError>

Similar to advance(), but does not advance the input, only returns a reference to the next len bytes.

Not to be confused with the struct-wide peeking functionality that switches between consuming the buffer and advancing a cursor.

pub fn local_peek_byte(&self, offset: usize) -> Result<u8, FormatError>

Similar to local_peek_bytes(), but returns a single byte.

Not to be confused with the struct-wide peeking functionality that switches between consuming the buffer and advancing a cursor.

pub fn start_peek(&mut self)

pub fn peek_cursor(&self) -> usize

The peek cursor from the view of the current innermost peek.

pub fn end_peek(&mut self) -> bool

End a peek and proceed with normal input processing. This method can only be used after a peek is started. If there was no ongoing peek, the method will panic.

Returns true if the peek pass is over, false if there is still an outer peek being processed.