pub struct EnumWithSerde<L: LinkingScheme> {
pub ty: Enum<L>,
pub serde: ContainerSerdeMetadata,
}Fields
ty: Enum<L>serde: ContainerSerdeMetadataTrait Implementations
Sourceimpl<L> BorshDeserialize for EnumWithSerde<L>where
L: BorshDeserialize + LinkingScheme,
impl<L> BorshDeserialize for EnumWithSerde<L>where
L: BorshDeserialize + LinkingScheme,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<L> BorshSerialize for EnumWithSerde<L>where
L: BorshSerialize + LinkingScheme,
impl<L> BorshSerialize for EnumWithSerde<L>where
L: BorshSerialize + LinkingScheme,
Sourceimpl<L: Clone + LinkingScheme> Clone for EnumWithSerde<L>
impl<L: Clone + LinkingScheme> Clone for EnumWithSerde<L>
Sourcefn clone(&self) -> EnumWithSerde<L>
fn clone(&self) -> EnumWithSerde<L>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<L: Debug + LinkingScheme> Debug for EnumWithSerde<L>
impl<L: Debug + LinkingScheme> Debug for EnumWithSerde<L>
Sourceimpl<L: LinkingScheme> From<Enum<L>> for EnumWithSerde<L>
impl<L: LinkingScheme> From<Enum<L>> for EnumWithSerde<L>
Sourceimpl<L: LinkingScheme> From<EnumWithSerde<L>> for Enum<L>
impl<L: LinkingScheme> From<EnumWithSerde<L>> for Enum<L>
Sourcefn from(value: EnumWithSerde<L>) -> Self
fn from(value: EnumWithSerde<L>) -> Self
Converts to this type from the input type.
Sourceimpl<L: PartialEq + LinkingScheme> PartialEq for EnumWithSerde<L>
impl<L: PartialEq + LinkingScheme> PartialEq for EnumWithSerde<L>
impl<L: Eq + LinkingScheme> Eq for EnumWithSerde<L>
impl<L: LinkingScheme> StructuralPartialEq for EnumWithSerde<L>