pub enum RollupRoots {
Transaction = 0,
UnsignedTransaction = 1,
RuntimeCall = 2,
Address = 3,
}Expand description
Not enforced in the types, but the expected convention that should be followed when generating the schema.
Variants