Module safe_string

Module safe_string 

Structs

SizedSafeString
A String wrapper which enforces certain constraints to ensure it is safely displayable as part of a transaction without confusing the user. Only printable ASCII is allowed, and the length is limited.

Enums

SchemaStringError

Constants

DEFAULT_MAX_STRING_LENGTH

Type Aliases

SafeString