pub struct ChainData {
pub chain_id: u64,
pub chain_name: String,
}Expand description
The standard metadata format for every chain. Includes a numeric chain_id and a human-readable chain name.
Fields
chain_id: u64chain_name: StringTrait Implementations
Sourceimpl BorshDeserialize for ChainData
impl BorshDeserialize for ChainData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ChainData
impl BorshSerialize for ChainData