pub struct IndexLinking;Trait Implementations
Sourceimpl BorshDeserialize for IndexLinking
impl BorshDeserialize for IndexLinking
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IndexLinking
impl BorshSerialize for IndexLinking
Sourceimpl Clone for IndexLinking
impl Clone for IndexLinking
Sourcefn clone(&self) -> IndexLinking
fn clone(&self) -> IndexLinking
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexLinking
impl Debug for IndexLinking
Sourceimpl LinkingScheme for IndexLinking
impl LinkingScheme for IndexLinking
Sourceimpl PartialEq for IndexLinking
impl PartialEq for IndexLinking
impl Eq for IndexLinking
impl StructuralPartialEq for IndexLinking