OverrideSchema

Trait OverrideSchema 

pub trait OverrideSchema {
    type Output: UniversalWallet;
}
Establish that this type should use the Output type to generate its schema. This is appropriate for cases where different types represent the same kind of data structure. For instance, HashMap and BTreeMap both represent a Container::Map in the data model of the schema; their internal implementation differences don’t affect the shape of their schemas.

Note that, for types to be considered equivalent in the schema, their borsh and JSON serialisations must both also be equivalent.

Required Associated Types

Implementations on Foreign Types

Source

impl OverrideSchema for isize

Source

impl OverrideSchema for usize

Source

impl<K: UniversalWallet, V: UniversalWallet> OverrideSchema for BTreeMap<K, V>

Source

type Output = HashMap<K, V>

Source

impl<T: UniversalWallet> OverrideSchema for Box<T>

Source

impl<T: UniversalWallet> OverrideSchema for BTreeSet<T>

Source

impl<T: UniversalWallet> OverrideSchema for Rc<T>

Source

impl<T: UniversalWallet> OverrideSchema for Arc<T>

Source

impl<T: UniversalWallet> OverrideSchema for Cell<T>

Source

impl<T: UniversalWallet> OverrideSchema for RefCell<T>

Source

impl<T: UniversalWallet> OverrideSchema for UnsafeCell<T>

Source

impl<T: UniversalWallet> OverrideSchema for HashSet<T>

Source

impl<T: UniversalWallet> OverrideSchema for Mutex<T>

Source

impl<T: UniversalWallet> OverrideSchema for RwLock<T>

Implementors