Ty

Enum Ty 

pub enum Ty<L: LinkingScheme> {
Show 15 variants Enum(Enum<L>), Struct(Struct<L>), Tuple(Tuple<L>), Option { value: L::TypeLink, }, Integer(IntegerType, IntegerDisplay), ByteArray { len: usize, display: ByteDisplay, }, Float32, Float64, String, Boolean, Skip { len: usize, }, ByteVec { display: ByteDisplay, }, Array { len: usize, value: L::TypeLink, }, Vec { value: L::TypeLink, }, Map { key: L::TypeLink, value: L::TypeLink, },
}

Variants



Enum(Enum<L>)



Struct(Struct<L>)



Tuple(Tuple<L>)



Option

Fields

value: L::TypeLink


Integer(IntegerType, IntegerDisplay)



ByteArray

Fields

len: usize
display: ByteDisplay


Float32



Float64



String



Boolean



Skip

Fields

len: usize


ByteVec

Fields

display: ByteDisplay


Array

Fields

len: usize
value: L::TypeLink


Vec

Fields

value: L::TypeLink


Map

Fields

key: L::TypeLink
value: L::TypeLink

Implementations

Source

impl<L: LinkingScheme> Ty<L>

pub fn visit<V: TypeVisitor<L, M>, M>( &self, schema: &impl TypeResolver<LinkingScheme = L, Metadata = M>, visitor: &mut V, arg: V::Arg, ) -> V::ReturnType

Source

impl<L: LinkingScheme> Ty<L>

pub fn is_skip(&self) -> bool

Returns true if the type is a skip type

Source

impl Ty<IndexLinking>

pub fn fill_next_placholder(&mut self, child: Link)

Fills the next available placeholder in the type with the given link, panicking if no placeholder is available.

Source

impl<L: LinkingScheme> Ty<L>

pub fn is_primitive(&self) -> bool

pub fn parent_byte_references(&self) -> Vec<(usize, usize)>