pub struct ContainerSerdeMetadata {
pub name: String,
pub fields_or_variants: Vec<FieldOrVariantSerdeMetadata>,
}Fields
name: Stringfields_or_variants: Vec<FieldOrVariantSerdeMetadata>Trait Implementations
Sourceimpl BorshDeserialize for ContainerSerdeMetadata
impl BorshDeserialize for ContainerSerdeMetadata
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ContainerSerdeMetadata
impl Clone for ContainerSerdeMetadata
Sourcefn clone(&self) -> ContainerSerdeMetadata
fn clone(&self) -> ContainerSerdeMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContainerSerdeMetadata
impl Debug for ContainerSerdeMetadata
Sourceimpl Default for ContainerSerdeMetadata
impl Default for ContainerSerdeMetadata
Sourcefn default() -> ContainerSerdeMetadata
fn default() -> ContainerSerdeMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ContainerSerdeMetadata
impl PartialEq for ContainerSerdeMetadata
impl Eq for ContainerSerdeMetadata
impl StructuralPartialEq for ContainerSerdeMetadata