pub struct FieldOrVariantSerdeMetadata {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl BorshDeserialize for FieldOrVariantSerdeMetadata
impl BorshDeserialize for FieldOrVariantSerdeMetadata
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for FieldOrVariantSerdeMetadata
impl Clone for FieldOrVariantSerdeMetadata
Sourcefn clone(&self) -> FieldOrVariantSerdeMetadata
fn clone(&self) -> FieldOrVariantSerdeMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FieldOrVariantSerdeMetadata
impl Debug for FieldOrVariantSerdeMetadata
Sourceimpl Default for FieldOrVariantSerdeMetadata
impl Default for FieldOrVariantSerdeMetadata
Sourcefn default() -> FieldOrVariantSerdeMetadata
fn default() -> FieldOrVariantSerdeMetadata
Returns the “default value” for a type. Read more
impl Eq for FieldOrVariantSerdeMetadata
impl StructuralPartialEq for FieldOrVariantSerdeMetadata