pub struct Struct<L: LinkingScheme> {
pub type_name: String,
pub template: Option<String>,
pub peekable: bool,
pub fields: Vec<NamedField<L>>,
}Fields
type_name: Stringtemplate: Option<String>peekable: boolfields: Vec<NamedField<L>>Trait Implementations
Sourceimpl<L> BorshDeserialize for Struct<L>where
L: BorshDeserialize + LinkingScheme,
impl<L> BorshDeserialize for Struct<L>where
L: BorshDeserialize + LinkingScheme,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<L> BorshSerialize for Struct<L>where
L: BorshSerialize + LinkingScheme,
impl<L> BorshSerialize for Struct<L>where
L: BorshSerialize + LinkingScheme,
Sourceimpl<L: LinkingScheme> From<Struct<L>> for StructWithSerde<L>
impl<L: LinkingScheme> From<Struct<L>> for StructWithSerde<L>
Sourceimpl<L: LinkingScheme> From<StructWithSerde<L>> for Struct<L>
impl<L: LinkingScheme> From<StructWithSerde<L>> for Struct<L>
Sourcefn from(value: StructWithSerde<L>) -> Self
fn from(value: StructWithSerde<L>) -> Self
Converts to this type from the input type.
impl<L: Eq + LinkingScheme> Eq for Struct<L>
impl<L: LinkingScheme> StructuralPartialEq for Struct<L>