pub struct UnnamedField<L: LinkingScheme> {
pub value: L::TypeLink,
pub silent: bool,
pub doc: String,
}Fields
value: L::TypeLinksilent: booldoc: StringTrait Implementations
Sourceimpl<L: LinkingScheme> BorshDeserialize for UnnamedField<L>where
L::TypeLink: BorshDeserialize,
impl<L: LinkingScheme> BorshDeserialize for UnnamedField<L>where
L::TypeLink: BorshDeserialize,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<L: LinkingScheme> BorshSerialize for UnnamedField<L>where
L::TypeLink: BorshSerialize,
impl<L: LinkingScheme> BorshSerialize for UnnamedField<L>where
L::TypeLink: BorshSerialize,
Sourceimpl<L: Clone + LinkingScheme> Clone for UnnamedField<L>
impl<L: Clone + LinkingScheme> Clone for UnnamedField<L>
Sourcefn clone(&self) -> UnnamedField<L>
fn clone(&self) -> UnnamedField<L>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<L: Debug + LinkingScheme> Debug for UnnamedField<L>
impl<L: Debug + LinkingScheme> Debug for UnnamedField<L>
Sourceimpl<L: PartialEq + LinkingScheme> PartialEq for UnnamedField<L>
impl<L: PartialEq + LinkingScheme> PartialEq for UnnamedField<L>
impl<L: Eq + LinkingScheme> Eq for UnnamedField<L>
impl<L: LinkingScheme> StructuralPartialEq for UnnamedField<L>