LinkingScheme

Trait LinkingScheme 

pub trait LinkingScheme: Clone + Debug {
    type TypeLink: Clone + Debug + PartialEq + Eq + BorshSerialize + BorshDeserialize;
}

Required Associated Types

The type used to link to other types in the schema representation. Usually, this is an enum which represents primitives with an immediate value and complex types with some kind of pointer.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors