Module safe_string
sov_
universal_
wallet
0.3.0
Module safe_
string
Module Items
Structs
Enums
Constants
Type Aliases
In sov_
universal_
wallet::
schema
sov_universal_wallet
::
schema
Module
safe_
string
Structs

Sized
Safe
String
A String wrapper which enforces certain constraints to ensure it is safely displayable as part of a transaction without confusing the user. Only printable ASCII is allowed, and the length is limited.
Enums

Schema
String
Error
Constants

DEFAULT_
MAX_
STRING_
LENGTH
Type Aliases

Safe
String