pub struct SizedSafeString<const MAX_LEN: usize>(/* private fields */);Expand description
A String wrapper which enforces certain constraints to ensure it is safely displayable as part of a transaction without confusing the user. Only printable ASCII is allowed, and the length is limited.
UniversalWallet implementation is forbidden on std::String by default, to avoid the possibility
of untrusted input supplying highly confusing text that tricks users into misunderstanding the
transaction they are signing. SafeString enforces some constraints to mitigate this risk. If
you need to encode a large data blob such as a hex string, use a Vec<u8> with the
[sov_wallet(display = "hex")] attribute (or any of the other display styles). Avoid raw
Strings if possible.
If an actual String is absolutely necessary, then a newtype wrapper can be used, on which
UniversalWallet is derived manually.
Implementations
Sourceimpl<const MAX_LEN: usize> SizedSafeString<MAX_LEN>
impl<const MAX_LEN: usize> SizedSafeString<MAX_LEN>
pub fn as_str(&self) -> &str
Sourcepub const fn max_len(&self) -> usize
pub const fn max_len(&self) -> usize
A convenience method to get the maximum length of SafeString instance
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length (not capacity or max_length) of the string in bytes
Sourcepub fn try_push(&mut self, c: char) -> Result<(), SchemaStringError>
pub fn try_push(&mut self, c: char) -> Result<(), SchemaStringError>
Appends the given char`` to the end of this SizedSafeString` if possible.
Sourcepub const fn is_valid_char(c: char) -> bool
pub const fn is_valid_char(c: char) -> bool
Returns true if the character is a valid member of SizedSafeString