pub trait OverrideSchema {
type Output: UniversalWallet;
}Expand description
Establish that this type should use the Output type to generate its schema.
This is appropriate for cases where different types represent the same kind of data structure.
For instance, HashMap and BTreeMap both represent a Container::Map in the data model of the
schema; their internal implementation differences don’t affect the shape of their schemas.
Note that, for types to be considered equivalent in the schema, their borsh and JSON serialisations must both also be equivalent.