TransactionTemplateSet

Struct TransactionTemplateSet 

pub struct TransactionTemplateSet(pub BTreeMap<String, TransactionTemplate>);
Data structure denoting a set of templates on a type, indexed by (string) name.

Tuple Fields

0: BTreeMap<String, TransactionTemplate>

Implementations

Source

impl TransactionTemplateSet

Replace placeholder links in templates with actual typelinks from the schema (provided by the type’s child_links). Template placeholders must be IndexedPlaceholders because a template does not necessarily include placeholders for every field - some fields may be provided with pre-encoded default values and thus need to be skipped. The index allows looking up the correct type in the child_links vector.

pub fn concatenate_template_sets( template_sets: Vec<AttributeAndChildTemplateSet>, type_name_for_diagnostics: &'static str, ) -> Self

Input: a vector of template sets, normally one for each field of a type. Outputs: a merged template set. This means:

  • Every individual template is concatenated from each field portion of it, across the set of templates.
  • The entire set is enforced to be present on every field, so no fields are skipped.

The exception to the 2nd rule above is for templates only present in the set through field types (i.e. subtype templates). See the documentation of AttributeAndChildTemplateSet for a full explanation.

pub fn filter_enum_variant_templates( self, filter: Vec<String>, inherit_all: bool, variant_name_for_diagnostics: &'static str, ) -> Self

Explicitly filter which templates will be part of a given enum variant. Only templates whose name is in the list will be set on the variant. Additionally, any names in the list NOT present in the templates will cause an error.

Optionally, an override can be set to inherit all templates from the variant (primarily intended for use on the RuntimeCall, to inherit all templates from every module’s CallMessage). In this case, the filter list is only used for error checking, to explicitly enforce that all templates named in it MUST be present.

pub fn merge_enum_template_sets( template_sets: Vec<TransactionTemplateSet>, type_name_for_diagnostics: &'static str, ) -> Self